@@ -25,7 +25,7 @@
 
 #include <gpgmepp/context.h>
 #include <gpgme.h> // need it for gpgme_protocol_t :(
-#include <tdepimmacros.h>
+#include <tdemacros.h>
 
 namespace GpgME {
   class ImportResult;
@@ -295,7 +295,7 @@ typedef unsigned long SigStatusFlags;
 
 class CryptPlugWrapper;
 
-class KDE_EXPORT CryptPlug {
+class TDE_EXPORT CryptPlug {
   friend class CryptPlugWrapper;
 protected:
   CryptPlug();
