@@ -34,7 +34,7 @@ class TDEShortcut;
 
 class CustomTemplates : public CustomTemplatesBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
