@@ -55,15 +55,15 @@ FavoriteFolderViewItem::FavoriteFolderViewItem(FavoriteFolderView * parent, cons
 {
   // same stuff as in KMFolderTreeItem again, this time even with virtual methods working
   init();
-  connect( folder, TQT_SIGNAL(nameChanged()), TQT_SLOT(nameChanged()) );
-  connect( folder, TQT_SIGNAL(iconsChanged()), TQT_SLOT(slotIconsChanged()) );
+  connect( folder, TQ_SIGNAL(nameChanged()), TQ_SLOT(nameChanged()) );
+  connect( folder, TQ_SIGNAL(iconsChanged()), TQ_SLOT(slotIconsChanged()) );
 
-  connect( folder, TQT_SIGNAL(msgAdded(KMFolder*,TQ_UINT32)), TQT_SLOT(updateCount()) );
-  connect( folder, TQT_SIGNAL(numUnreadMsgsChanged(KMFolder*)), TQT_SLOT(updateCount()) );
-  connect( folder, TQT_SIGNAL(msgRemoved(KMFolder*)), TQT_SLOT(updateCount()) );
-  connect( folder, TQT_SIGNAL(folderSizeChanged( KMFolder* )), TQT_SLOT(updateCount()) );
+  connect( folder, TQ_SIGNAL(msgAdded(KMFolder*,TQ_UINT32)), TQ_SLOT(updateCount()) );
+  connect( folder, TQ_SIGNAL(numUnreadMsgsChanged(KMFolder*)), TQ_SLOT(updateCount()) );
+  connect( folder, TQ_SIGNAL(msgRemoved(KMFolder*)), TQ_SLOT(updateCount()) );
+  connect( folder, TQ_SIGNAL(folderSizeChanged( KMFolder* )), TQ_SLOT(updateCount()) );
 
-  TQTimer::singleShot( 0, this, TQT_SLOT(updateCount()) );
+  TQTimer::singleShot( 0, this, TQ_SLOT(updateCount()) );
 
   if ( unreadCount() > 0 )
     setPixmap( 0, unreadIcon( iconSize() ) );
@@ -97,23 +97,23 @@ FavoriteFolderView::FavoriteFolderView( KMMainWidget *mainWidget, TQWidget * par
   setSorting( -1 );
   setShowSortIndicator( false );
 
-  connect( this, TQT_SIGNAL(selectionChanged()), TQT_SLOT(selectionChanged()) );
-  connect( this, TQT_SIGNAL(clicked(TQListViewItem*)), TQT_SLOT(itemClicked(TQListViewItem*)) );
-  connect( this, TQT_SIGNAL(dropped(TQDropEvent*,TQListViewItem*)), TQT_SLOT(dropped(TQDropEvent*,TQListViewItem*)) );
-  connect( this, TQT_SIGNAL(contextMenuRequested(TQListViewItem*, const TQPoint &, int)),
-           TQT_SLOT(contextMenu(TQListViewItem*,const TQPoint&)) );
-  connect( this, TQT_SIGNAL(moved()), TQT_SLOT(notifyInstancesOnChange()) );
-  connect( this, TQT_SIGNAL(triggerRefresh()), TQT_SLOT(refresh()) );
+  connect( this, TQ_SIGNAL(selectionChanged()), TQ_SLOT(selectionChanged()) );
+  connect( this, TQ_SIGNAL(clicked(TQListViewItem*)), TQ_SLOT(itemClicked(TQListViewItem*)) );
+  connect( this, TQ_SIGNAL(dropped(TQDropEvent*,TQListViewItem*)), TQ_SLOT(dropped(TQDropEvent*,TQListViewItem*)) );
+  connect( this, TQ_SIGNAL(contextMenuRequested(TQListViewItem*, const TQPoint &, int)),
+           TQ_SLOT(contextMenu(TQListViewItem*,const TQPoint&)) );
+  connect( this, TQ_SIGNAL(moved()), TQ_SLOT(notifyInstancesOnChange()) );
+  connect( this, TQ_SIGNAL(triggerRefresh()), TQ_SLOT(refresh()) );
 
-  connect( kmkernel->folderMgr(), TQT_SIGNAL(changed()), TQT_SLOT(initializeFavorites()) );
-  connect( kmkernel->dimapFolderMgr(), TQT_SIGNAL(changed()), TQT_SLOT(initializeFavorites()) );
-  connect( kmkernel->imapFolderMgr(), TQT_SIGNAL(changed()), TQT_SLOT(initializeFavorites()) );
-  connect( kmkernel->searchFolderMgr(), TQT_SIGNAL(changed()), TQT_SLOT(initializeFavorites()) );
+  connect( kmkernel->folderMgr(), TQ_SIGNAL(changed()), TQ_SLOT(initializeFavorites()) );
+  connect( kmkernel->dimapFolderMgr(), TQ_SIGNAL(changed()), TQ_SLOT(initializeFavorites()) );
+  connect( kmkernel->imapFolderMgr(), TQ_SIGNAL(changed()), TQ_SLOT(initializeFavorites()) );
+  connect( kmkernel->searchFolderMgr(), TQ_SIGNAL(changed()), TQ_SLOT(initializeFavorites()) );
 
-  connect( kmkernel->folderMgr(), TQT_SIGNAL(folderRemoved(KMFolder*)), TQT_SLOT(folderRemoved(KMFolder*)) );
-  connect( kmkernel->dimapFolderMgr(), TQT_SIGNAL(folderRemoved(KMFolder*)), TQT_SLOT(folderRemoved(KMFolder*)) );
-  connect( kmkernel->imapFolderMgr(), TQT_SIGNAL(folderRemoved(KMFolder*)), TQT_SLOT(folderRemoved(KMFolder*)) );
-  connect( kmkernel->searchFolderMgr(), TQT_SIGNAL(folderRemoved(KMFolder*)), TQT_SLOT(folderRemoved(KMFolder*)) );
+  connect( kmkernel->folderMgr(), TQ_SIGNAL(folderRemoved(KMFolder*)), TQ_SLOT(folderRemoved(KMFolder*)) );
+  connect( kmkernel->dimapFolderMgr(), TQ_SIGNAL(folderRemoved(KMFolder*)), TQ_SLOT(folderRemoved(KMFolder*)) );
+  connect( kmkernel->imapFolderMgr(), TQ_SIGNAL(folderRemoved(KMFolder*)), TQ_SLOT(folderRemoved(KMFolder*)) );
+  connect( kmkernel->searchFolderMgr(), TQ_SIGNAL(folderRemoved(KMFolder*)), TQ_SLOT(folderRemoved(KMFolder*)) );
 
   TQFont f = font();
   f.setItalic( true );
@@ -153,7 +153,7 @@ void FavoriteFolderView::readConfig()
     ensureItemVisible( firstChild() );
 
   // folder tree is not yet populated at this point
-  TQTimer::singleShot( 0, this, TQT_SLOT(initializeFavorites()) );
+  TQTimer::singleShot( 0, this, TQ_SLOT(initializeFavorites()) );
 
   readColorConfig();
   mReadingConfig = false;
@@ -334,18 +334,18 @@ void FavoriteFolderView::contextMenu(TQListViewItem * item, const TQPoint & poin
        mainWidget()->action("empty")->plug( &contextMenu );
     contextMenu.insertSeparator();
 
-    contextMenu.insertItem( SmallIconSet("configure_shortcuts"), i18n("&Assign Shortcut..."), fti, TQT_SLOT(assignShortcut()) );
-    contextMenu.insertItem( i18n("Expire..."), fti, TQT_SLOT(slotShowExpiryProperties()) );
+    contextMenu.insertItem( SmallIconSet("configure_shortcuts"), i18n("&Assign Shortcut..."), fti, TQ_SLOT(assignShortcut()) );
+    contextMenu.insertItem( i18n("Expire..."), fti, TQ_SLOT(slotShowExpiryProperties()) );
     mainWidget()->action("modify")->plug( &contextMenu );
     contextMenu.insertSeparator();
 
     contextMenu.insertItem( SmallIconSet("edit-delete"), i18n("Remove From Favorites"),
-                            this, TQT_SLOT(removeFolder()) );
-    contextMenu.insertItem( SmallIconSet("edit"), i18n("Rename Favorite"), this, TQT_SLOT(renameFolder()) );
+                            this, TQ_SLOT(removeFolder()) );
+    contextMenu.insertItem( SmallIconSet("edit"), i18n("Rename Favorite"), this, TQ_SLOT(renameFolder()) );
 
   } else {
     contextMenu.insertItem( SmallIconSet("bookmark_add"), i18n("Add Favorite Folder..."),
-                            this, TQT_SLOT(addFolder()) );
+                            this, TQ_SLOT(addFolder()) );
   }
   contextMenu.exec( point, 0 );
 }
