@@ -114,8 +114,8 @@ void KOEditorGeneral::initHeader( TQWidget *parent,TQBoxLayout *topLayout)
 
   mSummaryEdit = new FocusLineEdit( parent );
   TQWhatsThis::add( mSummaryEdit, whatsThis );
-  connect( mSummaryEdit, TQT_SIGNAL( focusReceivedSignal() ),
-           TQT_SIGNAL( focusReceivedSignal() ) );
+  connect( mSummaryEdit, TQ_SIGNAL( focusReceivedSignal() ),
+           TQ_SIGNAL( focusReceivedSignal() ) );
   headerLayout->addWidget(mSummaryEdit,1,1);
   summaryLabel->setBuddy( mSummaryEdit );
 
@@ -152,7 +152,7 @@ void KOEditorGeneral::initHeader( TQWidget *parent,TQBoxLayout *topLayout)
   mCategoriesButton = new TQPushButton( parent );
   mCategoriesButton->setText(i18n("Select..."));
   TQWhatsThis::add( mCategoriesButton, whatsThis );
-  connect(mCategoriesButton,TQT_SIGNAL(clicked()),TQT_SLOT(selectCategories()));
+  connect(mCategoriesButton,TQ_SIGNAL(clicked()),TQ_SLOT(selectCategories()));
   thirdLineLayout->addWidget( mCategoriesButton );
 }
 
@@ -209,7 +209,7 @@ void KOEditorGeneral::initAlarm( TQWidget *parent, TQBoxLayout *topLayout )
                    i18n( "Push this button to create an advanced set of reminders "
                          "for this event or to-do." ) );
   TQToolTip::add( mAlarmAdvancedButton, i18n( "Set an advanced reminder" ) );
-  connect( mAlarmAdvancedButton, TQT_SIGNAL(clicked()), TQT_SLOT(editAlarms()) );
+  connect( mAlarmAdvancedButton, TQ_SIGNAL(clicked()), TQ_SLOT(editAlarms()) );
   alarmLayout->addWidget( mAlarmAdvancedButton );
 
   mSimpleAlarmBox = new TQHBox( parent );
@@ -247,17 +247,17 @@ void KOEditorGeneral::initAlarm( TQWidget *parent, TQBoxLayout *topLayout )
   mAlarmTimeEdit->setEnabled( false );
   mAlarmIncrCombo->setEnabled( false );
   mAlarmInfoLabel->setEnabled( false );
-  connect( mAlarmButton, TQT_SIGNAL(toggled(bool)), mAlarmAdvancedButton, TQT_SLOT(setEnabled(bool)) );
-  connect( mAlarmButton, TQT_SIGNAL(toggled(bool)), mAlarmTimeEdit, TQT_SLOT(setEnabled(bool)) );
-  connect( mAlarmButton, TQT_SIGNAL(toggled(bool)), mAlarmIncrCombo, TQT_SLOT(setEnabled(bool)) );
-  connect( mAlarmButton, TQT_SIGNAL(toggled(bool)), mAlarmInfoLabel, TQT_SLOT(setEnabled(bool)) );
+  connect( mAlarmButton, TQ_SIGNAL(toggled(bool)), mAlarmAdvancedButton, TQ_SLOT(setEnabled(bool)) );
+  connect( mAlarmButton, TQ_SIGNAL(toggled(bool)), mAlarmTimeEdit, TQ_SLOT(setEnabled(bool)) );
+  connect( mAlarmButton, TQ_SIGNAL(toggled(bool)), mAlarmIncrCombo, TQ_SLOT(setEnabled(bool)) );
+  connect( mAlarmButton, TQ_SIGNAL(toggled(bool)), mAlarmInfoLabel, TQ_SLOT(setEnabled(bool)) );
 }
 
 void KOEditorGeneral::initAttachments(TQWidget *parent,TQBoxLayout *topLayout)
 {
   mAttachments = new KOEditorAttachments( KDialog::spacingHint(), parent );
-  connect( mAttachments, TQT_SIGNAL( openURL( const KURL & ) ) ,
-           this, TQT_SIGNAL( openURL( const KURL & ) ) );
+  connect( mAttachments, TQ_SIGNAL( openURL( const KURL & ) ) ,
+           this, TQ_SIGNAL( openURL( const KURL & ) ) );
   topLayout->addWidget( mAttachments, 1 );
 }
 
@@ -290,8 +290,8 @@ void KOEditorGeneral::selectCategories()
   KOGlobals::fitDialogToScreen( categoryDialog );
   categoryDialog->setSelected( mCategories );
 
-  connect(categoryDialog, TQT_SIGNAL(editCategories()), this, TQT_SIGNAL(openCategoryDialog()));
-  connect(this, TQT_SIGNAL(updateCategoryConfig()), categoryDialog, TQT_SLOT(updateCategoryConfig()));
+  connect(categoryDialog, TQ_SIGNAL(editCategories()), this, TQ_SIGNAL(openCategoryDialog()));
+  connect(this, TQ_SIGNAL(updateCategoryConfig()), categoryDialog, TQ_SLOT(updateCategoryConfig()));
 
   if ( categoryDialog->exec() ) {
     setCategories( categoryDialog->selectedCategories() );
@@ -573,7 +573,7 @@ void KOEditorGeneral::setDescription( const TQString &text )
 
 TQObject *KOEditorGeneral::typeAheadReceiver() const
 {
-  return TQT_TQOBJECT(mSummaryEdit);
+  return mSummaryEdit;
 }
 
 void KOEditorGeneral::updateAttendeeSummary(int count)
