@@ -28,7 +28,7 @@
 
 #include <tderesources/resource.h>
 #include <tderesources/configwidget.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 #include "libkcal_export.h"
 
