@@ -1341,9 +1341,7 @@ int vcaltime_utc_offset( TQDateTime ictt, TQString tzid )
   //  struct icaltimetype tt = icaltime_from_timet( ictt.toTime_t(), false );
   //  return icaltime_utc_offset( tt, tzid.latin1() );
   int daylight;
-  struct icaltimetype tt = icaltime_from_timet( ictt.toTime_t(), false );
-  //source says this is DEPRECATED, but it doesn't say what to use instead
-  //how to handle failure from icaltimezone_get_builtin_timezone_from_tzid()?
+  struct icaltimetype tt = icaltime_from_timet_with_zone( ictt.toTime_t(), false, NULL);
   return icaltimezone_get_utc_offset(
     icaltimezone_get_builtin_timezone( tzid.latin1() ),
     &tt, &daylight );
